import pygame
import os
import random
from featherlib.objects import *
from featherlib.feeding import *

class Parrot(Object):
    tut = "Your parrot to clean, feed, and abuse. Er, amuse. If depressed will pluck his feathers out."
    pri = 0
    def __init__(self,pos):
        self.timers = {"diet":5,"health":0,"amusement":1,"hygene":5,"pluck":1,"cravings":5,"likes":2,"speak":10}   #Standard seconds before each stat drops
        self.amount = {"diet":5,"health":0,"amusement":1,"hygene":5,"likes":1}  #Standard points the stat will drop (health is 0 unless bird is sick)
        self.sliders = {"diet":50,"health":50,"amusement":50,"hygene":50,"feathers":100}
        self.slider_events = {"pluck":self.pluck,"default":self.subtract_slider,
                                    "cravings":self.new_craving,"likes":self.adjust_likes,
                                    "speak":self.speak}
        self.slider_delays = {"diet":300,"health":300,"amusement":300,"hygene":300,"pluck":300,"cravings":300,"likes":300}
        for key in self.timers:
            self.slider_delays[key] = self.timers[key]*30
        self.base = pygame.image.load("parrot-small.png")
        self.bob = pygame.image.load("parrot-small-bob.png")
        self.cage = pygame.image.load("cage.png")
        self.small = self.base
        self.nextswitch = 15
        self.bobbing = False
        Object.__init__(self,self.base,pos)
        self.poisons = [random.choice(["Seeds","Seeds2"])]
        #Have a set of sliders for likes, -10 to 10, they slowly try to be 0
        self.toy_likes = {"newspaper":0,"blocks":0}
        self.food_likes = {"seeds":0,"carrot":0,"lettuce":0}
        self.music_likes = {"The Freeworld":0,"off":0,"Out Of My Mind":0,"peu":0}
        self.spot_likes = {"top":0,"bottom":0,"left":0,"right":0}
        self.new_craving("x")
        self.sound = None
        self.voices = True
        self.bowl = None
        self.badmusic = False
        self.bored = False
    def playsound(self,sound):
        if self.sound and self.sound.get_busy():
            return
        if not self.voices:
            print "playing",sound
            return
        self.sound = pygame.mixer.Sound("sounds/"+sound+".ogg").play()
    def speak(self,key):
        #~ if random.randint(0,10)>5:
            #~ return
        ok = []
        food = [[x,am] for [x,am] in self.food_likes.items() if am>4]
        if food:
            food = random.choice(food)
            ok.append(food[0])
        if self.badmusic:
            ok.append("whatareyouplaying")
        if self.bored:
            ok.append("imbored")
        if ok:
            self.playsound(random.choice(ok))
    def pluck(self,key):
        if [1 for k in self.sliders if self.sliders[k]<=0]:
            self.sliders["feathers"]-=5
    def new_craving(self,key):
        for dict in [self.toy_likes,self.food_likes,self.music_likes]:
            ckey = None
            is_craving = [key for key in dict if dict[key] > 3]
            if not is_craving:
                ckey = random.choice(dict.keys())
                dict[ckey] = 10
            is_hated = [key for key in dict if dict[key] < -3]
            if not is_hated:
                keys = dict.keys()
                if ckey:
                    keys.remove(ckey)
                key = random.choice(keys)
                dict[key] = -10
            print dict
    def adjust_likes(self,key):
        print "adjustlikes"
        for dict in [self.toy_likes,self.food_likes,self.music_likes]:
            for key in dict:
                if dict[key]<0:
                    dict[key]+=self.amount["likes"]
                if dict[key]>0:
                    dict[key]-=self.amount["likes"]
    def subtract_slider(self,key):
        self.sliders[key]-=self.amount[key]
    def clickme(self,hand):
        if hand.pos[1]<self.pos[1]+20:
            return Object.clickme(self,hand)
        feeding(self,hand,self.scene)
    def draw(self,window,usemid=False):
        if self.bobbing:
            self.nextswitch -= 1
            if self.nextswitch == 0:
                self.nextswitch = 15
                self.small = {self.base:self.bob,self.bob:self.base}[self.small]
        Object.draw(self,window,usemid)
        dp = [self.pos[0]-45,self.pos[1]-5]
        if usemid:
            dp = [self.pos[0]-self.size()[0]//2-45,
                    self.pos[1]-self.size()[1]//2-5]
        window.blit(self.cage,dp)
    def use(self,hand,o):
        z = feeding(self,hand,o.scene)
    def apply_ob(self,o):
        if not hasattr(o,"affect_sliders"):
            return
        for key in o.affect_sliders:
            self.sliders[key]+=o.affect_sliders[key]
            self.slider_delays[key] = getattr(o,"set_timers",{}).get(key,self.timers[key])
            return
    def is_poison(self,object):
        if object.__class__.__name__ in self.poisons:
            return True
        return False